@@ -44,7 +44,7 @@ our @EXPORT_OK = qw(get post put delete postData putData postFile putFile);
 ## CONSTANTS
 #####
 our $TIMEOUT = 10;
-our $VERSION = "1.3.2";
+our $VERSION = "1.3.3";
 #####
 ## VARIABLES
 #####
@@ -63,9 +63,8 @@ sub new {
 		'debug'		=> $args{'debug'} || 0,
 		'verbose'	=> $args{'verbose'} || 0,
 		'result'	=> undef,
-		'timeout'	=> $args{'timeout'},
+		'timeout'	=> $args{'timeout'} || $TIMEOUT,
 	};
-	$self->{'timeout'} = $TIMEOUT if not (defined  $args{'timeout'});
 # create and store a cookie jar
 	my $cookie_jar = HTTP::Cookies->new(
 		autosave		=> 1,
@@ -88,7 +87,7 @@ sub new {
 # connect to the client
 	my $client = REST::Client->new(
 		host		=> $self->{'url'},
-		timeout		=> 10,
+		timeout		=> $self->{'timeout'},
 		useragent	=> $ua,
 		follow		=> 1,
 	);
@@ -323,15 +322,16 @@ sub _handleResponse () {
 		if (not defined $reftype) {
 			$self->_bomb("Can't decode undef type");
 		} elsif ($reftype eq 'ARRAY') {
-
-			$responsehash->{'arraycount'} = $#$responseJSON+1;
+			$self->_logV2("copying array");
+			$responsehash->{'content'}{'arraycount'} = $#$responseJSON+1;
 			for (my $i = 0; $i <= $#$responseJSON; $i++) {
-				$responsehash->{$i} = $responseJSON->[$i];
+				$responsehash->{'content'}{$i} = $responseJSON->[$i];
 			}
 		} elsif ($reftype eq 'SCALAR') {
 			$self->_bomb("Can't decode scalar type");
 		} elsif ($reftype eq 'HASH') {
-			$responsehash = dclone ($responseJSON);
+			$self->_logV2("copying hash");
+			$responsehash->{'content'} = $responseJSON;
 		}
 		$responsehash->{'reqstatus'} = 'OK';
 		$responsehash->{'httpstatus'} = $rc;
@@ -439,6 +439,14 @@ POST some data. Request three arguments : endpoint, mime-type and the appropriat
 
 PUT some data. Similar to postData
 
+=item C<postFile>
+
+Alias for compatibility for postData
+
+=item C<putFile>
+
+Alias for compatibility for putData
+
 =back
 
 =head1 RETURN VALUE
@@ -449,7 +457,7 @@ The returned value is structured like the following :
 
 the fields `httpstatus` (200, 403, etc) and `requstatus` (OK, CRIT) are always present.
 
-the content is in the hash itself if the data type is JSON, else in the field `content` if we have text or binary
+the field `content` is a hash (if the mime-type of the result is JSON), text or binary
 
 
 =head1 SEE ALSO
